@@ -45,7 +45,7 @@ setMethod("size", signature(x = "itemMatrix"),
         ## we could use colSums(x). we use our own C code.
         ## however, diff(x@data@p) is nearly as fast.
 
-        .Call("R_colSums_ngCMatrix", x@data)
+        .Call("R_colSums_ngCMatrix", x@data, PACKAGE="arules")
     }
 )
 
@@ -108,11 +108,12 @@ setAs("itemMatrix", "list",
 setMethod("LIST", signature(from = "itemMatrix"),
     function(from, decode = TRUE) {
         if (decode) {
-            to <- .Call("R_asList_ngCMatrix", from@data, itemLabels(from))
+            to <- .Call("R_asList_ngCMatrix", from@data, itemLabels(from),
+		    PACKAGE="arules")
             names(to) <- itemsetInfo(from)[["itemsetID"]]
             to
         } else
-            .Call("R_asList_ngCMatrix", from@data, NULL)
+            .Call("R_asList_ngCMatrix", from@data, NULL, PACKAGE="arules")
     }
 )
 
@@ -221,7 +222,8 @@ setMethod("%pin%", signature(x = "itemMatrix", table = "character"),
 setMethod("[", signature(x = "itemMatrix", i = "ANY", j = "ANY", drop = "ANY"),
     function(x, i, j, ..., drop) {
         if (!missing(i)) {
-            x@data <- .Call("R_colSubset_ngCMatrix", x@data, i)
+            x@data <- .Call("R_colSubset_ngCMatrix", x@data, i, 
+		    PACKAGE="arules")
             if (length(x@itemsetInfo))
                 x@itemsetInfo <- x@itemsetInfo[i,, drop = FALSE]
         }
@@ -229,7 +231,8 @@ setMethod("[", signature(x = "itemMatrix", i = "ANY", j = "ANY", drop = "ANY"),
             ## fixed thanks to a bug report by Seth Falcon (06/31/01)
             if (is.character(j)) 
                 j <- itemLabels(x) %in% j
-            x@data <- .Call("R_rowSubset_ngCMatrix", x@data, j)
+            x@data <- .Call("R_rowSubset_ngCMatrix", x@data, j, 
+		    PACKAGE="arules")
             if (length(x@itemInfo))
                 x@itemInfo <- x@itemInfo[j,, drop = FALSE]
         }
@@ -258,10 +261,12 @@ setMethod("c", signature(x = "itemMatrix"),
                                     y@itemInfo[n,, drop = FALSE])
             }
             if (any(k != seq_len(length(k))))
-                y@data <- .Call("R_recode_ngCMatrix", y@data, k)
+                y@data <- .Call("R_recode_ngCMatrix", y@data, k, 
+		    PACKAGE="arules")
             if (y@data@Dim[1] <  x@data@Dim[1])
                 y@data@Dim[1] <- x@data@Dim[1]
-            x@data <- .Call("R_cbind_ngCMatrix", x@data, y@data)
+            x@data <- .Call("R_cbind_ngCMatrix", x@data, y@data, 
+		    PACKAGE="arules")
         }
         validObject(x, complete = TRUE)
         x
@@ -276,7 +281,7 @@ setMethod("merge", signature(x="itemMatrix"),
 	dx <- t(x@data)
 	dy <- t(y@data)
 
-	dc <- t(.Call("R_cbind_ngCMatrix", dx, dy))
+	dc <- t(.Call("R_cbind_ngCMatrix", dx, dy, PACKAGE="arules"))
 
 	### FIXME: itemInfo only preserves labels
 	new("itemMatrix",
@@ -289,7 +294,7 @@ setMethod("merge", signature(x="itemMatrix"),
 
 setMethod("duplicated", signature(x = "itemMatrix"),
     function(x, incomparables = FALSE) {
-        i <- .Call("R_pnindex", x@data, NULL, FALSE)
+        i <- .Call("R_pnindex", x@data, NULL, FALSE, PACKAGE="arules")
         duplicated(i)
     }
 )
@@ -309,10 +314,10 @@ setMethod("match", signature(x = "itemMatrix", table = "itemMatrix"),
             table@data@Dim[1] <- table@data@Dim[1] + length(n)
         }
         if (any(k != seq_len(length(k))))
-            x@data <- .Call("R_recode_ngCMatrix", x@data, k)
+            x@data <- .Call("R_recode_ngCMatrix", x@data, k, PACKAGE="arules")
         if (x@data@Dim[1] <  table@data@Dim[1])
             x@data@Dim[1] <- table@data@Dim[1]
-        i <- .Call("R_pnindex", table@data, x@data, FALSE)
+        i <- .Call("R_pnindex", table@data, x@data, FALSE, PACKAGE="arules")
         match(i, seq_len(length(table)), nomatch = nomatch, 
                                          incomparables = incomparables)
     }
